# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/common/proto/header.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from modules.common.proto import error_code_pb2 as modules_dot_common_dot_proto_dot_error__code__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/common/proto/header.proto',
  package='apollo.common',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n!modules/common/proto/header.proto\x12\rapollo.common\x1a%modules/common/proto/error_code.proto\"\xe5\x01\n\x06Header\x12\x15\n\rtimestamp_sec\x18\x01 \x01(\x01\x12\x13\n\x0bmodule_name\x18\x02 \x01(\t\x12\x14\n\x0csequence_num\x18\x03 \x01(\r\x12\x17\n\x0flidar_timestamp\x18\x04 \x01(\x04\x12\x18\n\x10\x63\x61mera_timestamp\x18\x05 \x01(\x04\x12\x17\n\x0fradar_timestamp\x18\x06 \x01(\x04\x12\x12\n\x07version\x18\x07 \x01(\r:\x01\x31\x12\'\n\x06status\x18\x08 \x01(\x0b\x32\x17.apollo.common.StatusPb\x12\x10\n\x08\x66rame_id\x18\t \x01(\t'
  ,
  dependencies=[modules_dot_common_dot_proto_dot_error__code__pb2.DESCRIPTOR,])




_HEADER = _descriptor.Descriptor(
  name='Header',
  full_name='apollo.common.Header',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='timestamp_sec', full_name='apollo.common.Header.timestamp_sec', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='module_name', full_name='apollo.common.Header.module_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sequence_num', full_name='apollo.common.Header.sequence_num', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lidar_timestamp', full_name='apollo.common.Header.lidar_timestamp', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='camera_timestamp', full_name='apollo.common.Header.camera_timestamp', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='radar_timestamp', full_name='apollo.common.Header.radar_timestamp', index=5,
      number=6, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='version', full_name='apollo.common.Header.version', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='apollo.common.Header.status', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='frame_id', full_name='apollo.common.Header.frame_id', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=92,
  serialized_end=321,
)

_HEADER.fields_by_name['status'].message_type = modules_dot_common_dot_proto_dot_error__code__pb2._STATUSPB
DESCRIPTOR.message_types_by_name['Header'] = _HEADER
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Header = _reflection.GeneratedProtocolMessageType('Header', (_message.Message,), {
  'DESCRIPTOR' : _HEADER,
  '__module__' : 'modules.common.proto.header_pb2'
  # @@protoc_insertion_point(class_scope:apollo.common.Header)
  })
_sym_db.RegisterMessage(Header)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/drivers/proto/mobileye.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from modules.common.proto import header_pb2 as modules_dot_common_dot_proto_dot_header__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/drivers/proto/mobileye.proto',
  package='apollo.drivers',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n$modules/drivers/proto/mobileye.proto\x12\x0e\x61pollo.drivers\x1a!modules/common/proto/header.proto\"\xa3\x01\n\x07Lka_768\x12\x11\n\tlane_type\x18\x01 \x01(\x05\x12\x0f\n\x07quality\x18\x02 \x01(\x05\x12\x14\n\x0cmodel_degree\x18\x03 \x01(\x05\x12\x10\n\x08position\x18\x04 \x01(\x01\x12\x11\n\tcurvature\x18\x05 \x01(\x01\x12\x1c\n\x14\x63urvature_derivative\x18\x06 \x01(\x01\x12\x1b\n\x13width_right_marking\x18\x07 \x01(\x01\"1\n\x07Num_76b\x12&\n\x1enum_of_next_lane_mark_reported\x18\x01 \x01(\x05\"\xea\x01\n\x0f\x41\x66termarket_669\x12\x16\n\x0elane_conf_left\x18\x01 \x01(\x05\x12\x1d\n\x15ldw_availability_left\x18\x02 \x01(\x08\x12\x16\n\x0elane_type_left\x18\x03 \x01(\x05\x12\x1a\n\x12\x64istance_to_lane_l\x18\x04 \x01(\x01\x12\x17\n\x0flane_conf_right\x18\x05 \x01(\x05\x12\x1e\n\x16ldw_availability_right\x18\x06 \x01(\x08\x12\x17\n\x0flane_type_right\x18\x07 \x01(\x05\x12\x1a\n\x12\x64istance_to_lane_r\x18\x08 \x01(\x01\"U\n\x07Lka_769\x12\x15\n\rheading_angle\x18\x01 \x01(\x01\x12\x12\n\nview_range\x18\x02 \x01(\x01\x12\x1f\n\x17view_range_availability\x18\x03 \x01(\x08\"\xc3\x01\n\rReference_76a\x12\x1c\n\x14ref_point_1_position\x18\x01 \x01(\x01\x12\x1c\n\x14ref_point_1_distance\x18\x02 \x01(\x01\x12\x1c\n\x14ref_point_1_validity\x18\x03 \x01(\x08\x12\x1c\n\x14ref_point_2_position\x18\x04 \x01(\x01\x12\x1c\n\x14ref_point_2_distance\x18\x05 \x01(\x01\x12\x1c\n\x14ref_point_2_validity\x18\x06 \x01(\x08\"\x9c\x02\n\x0b\x44\x65tails_738\x12\x15\n\rnum_obstacles\x18\x01 \x01(\x05\x12\x11\n\ttimestamp\x18\x02 \x01(\x05\x12\x1b\n\x13\x61pplication_version\x18\x03 \x01(\x05\x12%\n\x1d\x61\x63tive_version_number_section\x18\x04 \x01(\x05\x12\x1e\n\x16left_close_rang_cut_in\x18\x05 \x01(\x08\x12\x1f\n\x17right_close_rang_cut_in\x18\x06 \x01(\x08\x12\n\n\x02go\x18\x07 \x01(\x05\x12\x18\n\x10protocol_version\x18\x08 \x01(\x05\x12\x11\n\tclose_car\x18\t \x01(\x08\x12\x10\n\x08\x66\x61ilsafe\x18\n \x01(\x05\x12\x13\n\x0breserved_10\x18\x0b \x01(\x05\"\xa0\x01\n\x08Next_76c\x12\x11\n\tlane_type\x18\x01 \x01(\x05\x12\x0f\n\x07quality\x18\x02 \x01(\x05\x12\x14\n\x0cmodel_degree\x18\x03 \x01(\x05\x12\x10\n\x08position\x18\x04 \x01(\x01\x12\x11\n\tcurvature\x18\x05 \x01(\x01\x12\x1c\n\x14\x63urvature_derivative\x18\x06 \x01(\x01\x12\x17\n\x0flane_mark_width\x18\x07 \x01(\x01\"\xd4\x01\n\x0b\x44\x65tails_737\x12\x16\n\x0elane_curvature\x18\x01 \x01(\x01\x12\x14\n\x0clane_heading\x18\x02 \x01(\x01\x12\x1c\n\x14\x63\x61_construction_area\x18\x03 \x01(\x08\x12\x1e\n\x16right_ldw_availability\x18\x04 \x01(\x08\x12\x1d\n\x15left_ldw_availability\x18\x05 \x01(\x08\x12\x12\n\nreserved_1\x18\x06 \x01(\x08\x12\x11\n\tyaw_angle\x18\x07 \x01(\x01\x12\x13\n\x0bpitch_angle\x18\x08 \x01(\x01\"U\n\x07Lka_767\x12\x15\n\rheading_angle\x18\x01 \x01(\x01\x12\x12\n\nview_range\x18\x02 \x01(\x01\x12\x1f\n\x17view_range_availability\x18\x03 \x01(\x08\"\xa2\x01\n\x07Lka_766\x12\x11\n\tlane_type\x18\x01 \x01(\x05\x12\x0f\n\x07quality\x18\x02 \x01(\x05\x12\x14\n\x0cmodel_degree\x18\x03 \x01(\x05\x12\x10\n\x08position\x18\x04 \x01(\x01\x12\x11\n\tcurvature\x18\x05 \x01(\x01\x12\x1c\n\x14\x63urvature_derivative\x18\x06 \x01(\x01\x12\x1a\n\x12width_left_marking\x18\x07 \x01(\x01\"V\n\x08Next_76d\x12\x15\n\rheading_angle\x18\x01 \x01(\x01\x12\x12\n\nview_range\x18\x02 \x01(\x01\x12\x1f\n\x17view_range_availability\x18\x03 \x01(\x08\"\xbe\x02\n\x0b\x44\x65tails_739\x12\x13\n\x0bobstacle_id\x18\x01 \x01(\x05\x12\x16\n\x0eobstacle_pos_x\x18\x02 \x01(\x01\x12\x11\n\treseved_2\x18\x03 \x01(\x05\x12\x16\n\x0eobstacle_pos_y\x18\x04 \x01(\x01\x12\x14\n\x0c\x62linker_info\x18\x05 \x01(\x05\x12\x16\n\x0e\x63ut_in_and_out\x18\x06 \x01(\x05\x12\x1a\n\x12obstacle_rel_vel_x\x18\x07 \x01(\x01\x12\x15\n\robstacle_type\x18\x08 \x01(\x05\x12\x12\n\nreserved_3\x18\t \x01(\x08\x12\x17\n\x0fobstacle_status\x18\n \x01(\x05\x12\x1d\n\x15obstacle_brake_lights\x18\x0b \x01(\x08\x12\x12\n\nreserved_4\x18\x0c \x01(\x05\x12\x16\n\x0eobstacle_valid\x18\r \x01(\x05\"\x9e\x02\n\x0b\x44\x65tails_73a\x12\x17\n\x0fobstacle_length\x18\x01 \x01(\x01\x12\x16\n\x0eobstacle_width\x18\x02 \x01(\x01\x12\x14\n\x0cobstacle_age\x18\x03 \x01(\x05\x12\x15\n\robstacle_lane\x18\x04 \x01(\x05\x12\x11\n\tcipv_flag\x18\x05 \x01(\x08\x12\x12\n\nreserved_5\x18\x06 \x01(\x08\x12\x13\n\x0bradar_pos_x\x18\x07 \x01(\x01\x12\x13\n\x0bradar_vel_x\x18\x08 \x01(\x01\x12\x1e\n\x16radar_match_confidence\x18\t \x01(\x05\x12\x12\n\nreserved_6\x18\n \x01(\x08\x12\x18\n\x10matched_radar_id\x18\x0b \x01(\x05\x12\x12\n\nreserved_7\x18\x0c \x01(\x08\"\xbc\x01\n\x0b\x44\x65tails_73b\x12\x1b\n\x13obstacle_angle_rate\x18\x01 \x01(\x01\x12\x1d\n\x15obstacle_scale_change\x18\x02 \x01(\x01\x12\x16\n\x0eobject_accel_x\x18\x03 \x01(\x01\x12\x12\n\nreserved_8\x18\x04 \x01(\x05\x12\x19\n\x11obstacle_replaced\x18\x05 \x01(\x08\x12\x12\n\nreserved_9\x18\x06 \x01(\x05\x12\x16\n\x0eobstacle_angle\x18\x07 \x01(\x01\"\xc5\x05\n\x08Mobileye\x12%\n\x06header\x18\x01 \x01(\x0b\x32\x15.apollo.common.Header\x12\x38\n\x0f\x61\x66termarket_669\x18\x02 \x01(\x0b\x32\x1f.apollo.drivers.Aftermarket_669\x12\x30\n\x0b\x64\x65tails_737\x18\x03 \x01(\x0b\x32\x1b.apollo.drivers.Details_737\x12\x30\n\x0b\x64\x65tails_738\x18\x04 \x01(\x0b\x32\x1b.apollo.drivers.Details_738\x12\x30\n\x0b\x64\x65tails_739\x18\x05 \x03(\x0b\x32\x1b.apollo.drivers.Details_739\x12\x30\n\x0b\x64\x65tails_73a\x18\x06 \x03(\x0b\x32\x1b.apollo.drivers.Details_73a\x12\x30\n\x0b\x64\x65tails_73b\x18\x07 \x03(\x0b\x32\x1b.apollo.drivers.Details_73b\x12(\n\x07lka_766\x18\x08 \x01(\x0b\x32\x17.apollo.drivers.Lka_766\x12(\n\x07lka_767\x18\t \x01(\x0b\x32\x17.apollo.drivers.Lka_767\x12(\n\x07lka_768\x18\n \x01(\x0b\x32\x17.apollo.drivers.Lka_768\x12(\n\x07lka_769\x18\x0b \x01(\x0b\x32\x17.apollo.drivers.Lka_769\x12\x34\n\rreference_76a\x18\x0c \x01(\x0b\x32\x1d.apollo.drivers.Reference_76a\x12(\n\x07num_76b\x18\r \x01(\x0b\x32\x17.apollo.drivers.Num_76b\x12*\n\x08next_76c\x18\x0e \x03(\x0b\x32\x18.apollo.drivers.Next_76c\x12*\n\x08next_76d\x18\x0f \x03(\x0b\x32\x18.apollo.drivers.Next_76d'
  ,
  dependencies=[modules_dot_common_dot_proto_dot_header__pb2.DESCRIPTOR,])




_LKA_768 = _descriptor.Descriptor(
  name='Lka_768',
  full_name='apollo.drivers.Lka_768',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='lane_type', full_name='apollo.drivers.Lka_768.lane_type', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='quality', full_name='apollo.drivers.Lka_768.quality', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='model_degree', full_name='apollo.drivers.Lka_768.model_degree', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='position', full_name='apollo.drivers.Lka_768.position', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='curvature', full_name='apollo.drivers.Lka_768.curvature', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='curvature_derivative', full_name='apollo.drivers.Lka_768.curvature_derivative', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='width_right_marking', full_name='apollo.drivers.Lka_768.width_right_marking', index=6,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=92,
  serialized_end=255,
)


_NUM_76B = _descriptor.Descriptor(
  name='Num_76b',
  full_name='apollo.drivers.Num_76b',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='num_of_next_lane_mark_reported', full_name='apollo.drivers.Num_76b.num_of_next_lane_mark_reported', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=257,
  serialized_end=306,
)


_AFTERMARKET_669 = _descriptor.Descriptor(
  name='Aftermarket_669',
  full_name='apollo.drivers.Aftermarket_669',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='lane_conf_left', full_name='apollo.drivers.Aftermarket_669.lane_conf_left', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ldw_availability_left', full_name='apollo.drivers.Aftermarket_669.ldw_availability_left', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lane_type_left', full_name='apollo.drivers.Aftermarket_669.lane_type_left', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='distance_to_lane_l', full_name='apollo.drivers.Aftermarket_669.distance_to_lane_l', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lane_conf_right', full_name='apollo.drivers.Aftermarket_669.lane_conf_right', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ldw_availability_right', full_name='apollo.drivers.Aftermarket_669.ldw_availability_right', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lane_type_right', full_name='apollo.drivers.Aftermarket_669.lane_type_right', index=6,
      number=7, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='distance_to_lane_r', full_name='apollo.drivers.Aftermarket_669.distance_to_lane_r', index=7,
      number=8, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=309,
  serialized_end=543,
)


_LKA_769 = _descriptor.Descriptor(
  name='Lka_769',
  full_name='apollo.drivers.Lka_769',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='heading_angle', full_name='apollo.drivers.Lka_769.heading_angle', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='view_range', full_name='apollo.drivers.Lka_769.view_range', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='view_range_availability', full_name='apollo.drivers.Lka_769.view_range_availability', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=545,
  serialized_end=630,
)


_REFERENCE_76A = _descriptor.Descriptor(
  name='Reference_76a',
  full_name='apollo.drivers.Reference_76a',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ref_point_1_position', full_name='apollo.drivers.Reference_76a.ref_point_1_position', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ref_point_1_distance', full_name='apollo.drivers.Reference_76a.ref_point_1_distance', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ref_point_1_validity', full_name='apollo.drivers.Reference_76a.ref_point_1_validity', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ref_point_2_position', full_name='apollo.drivers.Reference_76a.ref_point_2_position', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ref_point_2_distance', full_name='apollo.drivers.Reference_76a.ref_point_2_distance', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ref_point_2_validity', full_name='apollo.drivers.Reference_76a.ref_point_2_validity', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=633,
  serialized_end=828,
)


_DETAILS_738 = _descriptor.Descriptor(
  name='Details_738',
  full_name='apollo.drivers.Details_738',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='num_obstacles', full_name='apollo.drivers.Details_738.num_obstacles', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='apollo.drivers.Details_738.timestamp', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='application_version', full_name='apollo.drivers.Details_738.application_version', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='active_version_number_section', full_name='apollo.drivers.Details_738.active_version_number_section', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='left_close_rang_cut_in', full_name='apollo.drivers.Details_738.left_close_rang_cut_in', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='right_close_rang_cut_in', full_name='apollo.drivers.Details_738.right_close_rang_cut_in', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='go', full_name='apollo.drivers.Details_738.go', index=6,
      number=7, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='protocol_version', full_name='apollo.drivers.Details_738.protocol_version', index=7,
      number=8, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='close_car', full_name='apollo.drivers.Details_738.close_car', index=8,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='failsafe', full_name='apollo.drivers.Details_738.failsafe', index=9,
      number=10, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reserved_10', full_name='apollo.drivers.Details_738.reserved_10', index=10,
      number=11, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=831,
  serialized_end=1115,
)


_NEXT_76C = _descriptor.Descriptor(
  name='Next_76c',
  full_name='apollo.drivers.Next_76c',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='lane_type', full_name='apollo.drivers.Next_76c.lane_type', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='quality', full_name='apollo.drivers.Next_76c.quality', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='model_degree', full_name='apollo.drivers.Next_76c.model_degree', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='position', full_name='apollo.drivers.Next_76c.position', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='curvature', full_name='apollo.drivers.Next_76c.curvature', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='curvature_derivative', full_name='apollo.drivers.Next_76c.curvature_derivative', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lane_mark_width', full_name='apollo.drivers.Next_76c.lane_mark_width', index=6,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1118,
  serialized_end=1278,
)


_DETAILS_737 = _descriptor.Descriptor(
  name='Details_737',
  full_name='apollo.drivers.Details_737',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='lane_curvature', full_name='apollo.drivers.Details_737.lane_curvature', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lane_heading', full_name='apollo.drivers.Details_737.lane_heading', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ca_construction_area', full_name='apollo.drivers.Details_737.ca_construction_area', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='right_ldw_availability', full_name='apollo.drivers.Details_737.right_ldw_availability', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='left_ldw_availability', full_name='apollo.drivers.Details_737.left_ldw_availability', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reserved_1', full_name='apollo.drivers.Details_737.reserved_1', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='yaw_angle', full_name='apollo.drivers.Details_737.yaw_angle', index=6,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pitch_angle', full_name='apollo.drivers.Details_737.pitch_angle', index=7,
      number=8, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1281,
  serialized_end=1493,
)


_LKA_767 = _descriptor.Descriptor(
  name='Lka_767',
  full_name='apollo.drivers.Lka_767',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='heading_angle', full_name='apollo.drivers.Lka_767.heading_angle', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='view_range', full_name='apollo.drivers.Lka_767.view_range', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='view_range_availability', full_name='apollo.drivers.Lka_767.view_range_availability', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1495,
  serialized_end=1580,
)


_LKA_766 = _descriptor.Descriptor(
  name='Lka_766',
  full_name='apollo.drivers.Lka_766',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='lane_type', full_name='apollo.drivers.Lka_766.lane_type', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='quality', full_name='apollo.drivers.Lka_766.quality', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='model_degree', full_name='apollo.drivers.Lka_766.model_degree', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='position', full_name='apollo.drivers.Lka_766.position', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='curvature', full_name='apollo.drivers.Lka_766.curvature', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='curvature_derivative', full_name='apollo.drivers.Lka_766.curvature_derivative', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='width_left_marking', full_name='apollo.drivers.Lka_766.width_left_marking', index=6,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1583,
  serialized_end=1745,
)


_NEXT_76D = _descriptor.Descriptor(
  name='Next_76d',
  full_name='apollo.drivers.Next_76d',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='heading_angle', full_name='apollo.drivers.Next_76d.heading_angle', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='view_range', full_name='apollo.drivers.Next_76d.view_range', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='view_range_availability', full_name='apollo.drivers.Next_76d.view_range_availability', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1747,
  serialized_end=1833,
)


_DETAILS_739 = _descriptor.Descriptor(
  name='Details_739',
  full_name='apollo.drivers.Details_739',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='obstacle_id', full_name='apollo.drivers.Details_739.obstacle_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='obstacle_pos_x', full_name='apollo.drivers.Details_739.obstacle_pos_x', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reseved_2', full_name='apollo.drivers.Details_739.reseved_2', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='obstacle_pos_y', full_name='apollo.drivers.Details_739.obstacle_pos_y', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='blinker_info', full_name='apollo.drivers.Details_739.blinker_info', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cut_in_and_out', full_name='apollo.drivers.Details_739.cut_in_and_out', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='obstacle_rel_vel_x', full_name='apollo.drivers.Details_739.obstacle_rel_vel_x', index=6,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='obstacle_type', full_name='apollo.drivers.Details_739.obstacle_type', index=7,
      number=8, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reserved_3', full_name='apollo.drivers.Details_739.reserved_3', index=8,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='obstacle_status', full_name='apollo.drivers.Details_739.obstacle_status', index=9,
      number=10, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='obstacle_brake_lights', full_name='apollo.drivers.Details_739.obstacle_brake_lights', index=10,
      number=11, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reserved_4', full_name='apollo.drivers.Details_739.reserved_4', index=11,
      number=12, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='obstacle_valid', full_name='apollo.drivers.Details_739.obstacle_valid', index=12,
      number=13, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1836,
  serialized_end=2154,
)


_DETAILS_73A = _descriptor.Descriptor(
  name='Details_73a',
  full_name='apollo.drivers.Details_73a',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='obstacle_length', full_name='apollo.drivers.Details_73a.obstacle_length', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='obstacle_width', full_name='apollo.drivers.Details_73a.obstacle_width', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='obstacle_age', full_name='apollo.drivers.Details_73a.obstacle_age', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='obstacle_lane', full_name='apollo.drivers.Details_73a.obstacle_lane', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cipv_flag', full_name='apollo.drivers.Details_73a.cipv_flag', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reserved_5', full_name='apollo.drivers.Details_73a.reserved_5', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='radar_pos_x', full_name='apollo.drivers.Details_73a.radar_pos_x', index=6,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='radar_vel_x', full_name='apollo.drivers.Details_73a.radar_vel_x', index=7,
      number=8, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='radar_match_confidence', full_name='apollo.drivers.Details_73a.radar_match_confidence', index=8,
      number=9, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reserved_6', full_name='apollo.drivers.Details_73a.reserved_6', index=9,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='matched_radar_id', full_name='apollo.drivers.Details_73a.matched_radar_id', index=10,
      number=11, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reserved_7', full_name='apollo.drivers.Details_73a.reserved_7', index=11,
      number=12, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2157,
  serialized_end=2443,
)


_DETAILS_73B = _descriptor.Descriptor(
  name='Details_73b',
  full_name='apollo.drivers.Details_73b',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='obstacle_angle_rate', full_name='apollo.drivers.Details_73b.obstacle_angle_rate', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='obstacle_scale_change', full_name='apollo.drivers.Details_73b.obstacle_scale_change', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='object_accel_x', full_name='apollo.drivers.Details_73b.object_accel_x', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reserved_8', full_name='apollo.drivers.Details_73b.reserved_8', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='obstacle_replaced', full_name='apollo.drivers.Details_73b.obstacle_replaced', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reserved_9', full_name='apollo.drivers.Details_73b.reserved_9', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='obstacle_angle', full_name='apollo.drivers.Details_73b.obstacle_angle', index=6,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2446,
  serialized_end=2634,
)


_MOBILEYE = _descriptor.Descriptor(
  name='Mobileye',
  full_name='apollo.drivers.Mobileye',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='apollo.drivers.Mobileye.header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='aftermarket_669', full_name='apollo.drivers.Mobileye.aftermarket_669', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='details_737', full_name='apollo.drivers.Mobileye.details_737', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='details_738', full_name='apollo.drivers.Mobileye.details_738', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='details_739', full_name='apollo.drivers.Mobileye.details_739', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='details_73a', full_name='apollo.drivers.Mobileye.details_73a', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='details_73b', full_name='apollo.drivers.Mobileye.details_73b', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lka_766', full_name='apollo.drivers.Mobileye.lka_766', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lka_767', full_name='apollo.drivers.Mobileye.lka_767', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lka_768', full_name='apollo.drivers.Mobileye.lka_768', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lka_769', full_name='apollo.drivers.Mobileye.lka_769', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reference_76a', full_name='apollo.drivers.Mobileye.reference_76a', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='num_76b', full_name='apollo.drivers.Mobileye.num_76b', index=12,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_76c', full_name='apollo.drivers.Mobileye.next_76c', index=13,
      number=14, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_76d', full_name='apollo.drivers.Mobileye.next_76d', index=14,
      number=15, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2637,
  serialized_end=3346,
)

_MOBILEYE.fields_by_name['header'].message_type = modules_dot_common_dot_proto_dot_header__pb2._HEADER
_MOBILEYE.fields_by_name['aftermarket_669'].message_type = _AFTERMARKET_669
_MOBILEYE.fields_by_name['details_737'].message_type = _DETAILS_737
_MOBILEYE.fields_by_name['details_738'].message_type = _DETAILS_738
_MOBILEYE.fields_by_name['details_739'].message_type = _DETAILS_739
_MOBILEYE.fields_by_name['details_73a'].message_type = _DETAILS_73A
_MOBILEYE.fields_by_name['details_73b'].message_type = _DETAILS_73B
_MOBILEYE.fields_by_name['lka_766'].message_type = _LKA_766
_MOBILEYE.fields_by_name['lka_767'].message_type = _LKA_767
_MOBILEYE.fields_by_name['lka_768'].message_type = _LKA_768
_MOBILEYE.fields_by_name['lka_769'].message_type = _LKA_769
_MOBILEYE.fields_by_name['reference_76a'].message_type = _REFERENCE_76A
_MOBILEYE.fields_by_name['num_76b'].message_type = _NUM_76B
_MOBILEYE.fields_by_name['next_76c'].message_type = _NEXT_76C
_MOBILEYE.fields_by_name['next_76d'].message_type = _NEXT_76D
DESCRIPTOR.message_types_by_name['Lka_768'] = _LKA_768
DESCRIPTOR.message_types_by_name['Num_76b'] = _NUM_76B
DESCRIPTOR.message_types_by_name['Aftermarket_669'] = _AFTERMARKET_669
DESCRIPTOR.message_types_by_name['Lka_769'] = _LKA_769
DESCRIPTOR.message_types_by_name['Reference_76a'] = _REFERENCE_76A
DESCRIPTOR.message_types_by_name['Details_738'] = _DETAILS_738
DESCRIPTOR.message_types_by_name['Next_76c'] = _NEXT_76C
DESCRIPTOR.message_types_by_name['Details_737'] = _DETAILS_737
DESCRIPTOR.message_types_by_name['Lka_767'] = _LKA_767
DESCRIPTOR.message_types_by_name['Lka_766'] = _LKA_766
DESCRIPTOR.message_types_by_name['Next_76d'] = _NEXT_76D
DESCRIPTOR.message_types_by_name['Details_739'] = _DETAILS_739
DESCRIPTOR.message_types_by_name['Details_73a'] = _DETAILS_73A
DESCRIPTOR.message_types_by_name['Details_73b'] = _DETAILS_73B
DESCRIPTOR.message_types_by_name['Mobileye'] = _MOBILEYE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Lka_768 = _reflection.GeneratedProtocolMessageType('Lka_768', (_message.Message,), {
  'DESCRIPTOR' : _LKA_768,
  '__module__' : 'modules.drivers.proto.mobileye_pb2'
  # @@protoc_insertion_point(class_scope:apollo.drivers.Lka_768)
  })
_sym_db.RegisterMessage(Lka_768)

Num_76b = _reflection.GeneratedProtocolMessageType('Num_76b', (_message.Message,), {
  'DESCRIPTOR' : _NUM_76B,
  '__module__' : 'modules.drivers.proto.mobileye_pb2'
  # @@protoc_insertion_point(class_scope:apollo.drivers.Num_76b)
  })
_sym_db.RegisterMessage(Num_76b)

Aftermarket_669 = _reflection.GeneratedProtocolMessageType('Aftermarket_669', (_message.Message,), {
  'DESCRIPTOR' : _AFTERMARKET_669,
  '__module__' : 'modules.drivers.proto.mobileye_pb2'
  # @@protoc_insertion_point(class_scope:apollo.drivers.Aftermarket_669)
  })
_sym_db.RegisterMessage(Aftermarket_669)

Lka_769 = _reflection.GeneratedProtocolMessageType('Lka_769', (_message.Message,), {
  'DESCRIPTOR' : _LKA_769,
  '__module__' : 'modules.drivers.proto.mobileye_pb2'
  # @@protoc_insertion_point(class_scope:apollo.drivers.Lka_769)
  })
_sym_db.RegisterMessage(Lka_769)

Reference_76a = _reflection.GeneratedProtocolMessageType('Reference_76a', (_message.Message,), {
  'DESCRIPTOR' : _REFERENCE_76A,
  '__module__' : 'modules.drivers.proto.mobileye_pb2'
  # @@protoc_insertion_point(class_scope:apollo.drivers.Reference_76a)
  })
_sym_db.RegisterMessage(Reference_76a)

Details_738 = _reflection.GeneratedProtocolMessageType('Details_738', (_message.Message,), {
  'DESCRIPTOR' : _DETAILS_738,
  '__module__' : 'modules.drivers.proto.mobileye_pb2'
  # @@protoc_insertion_point(class_scope:apollo.drivers.Details_738)
  })
_sym_db.RegisterMessage(Details_738)

Next_76c = _reflection.GeneratedProtocolMessageType('Next_76c', (_message.Message,), {
  'DESCRIPTOR' : _NEXT_76C,
  '__module__' : 'modules.drivers.proto.mobileye_pb2'
  # @@protoc_insertion_point(class_scope:apollo.drivers.Next_76c)
  })
_sym_db.RegisterMessage(Next_76c)

Details_737 = _reflection.GeneratedProtocolMessageType('Details_737', (_message.Message,), {
  'DESCRIPTOR' : _DETAILS_737,
  '__module__' : 'modules.drivers.proto.mobileye_pb2'
  # @@protoc_insertion_point(class_scope:apollo.drivers.Details_737)
  })
_sym_db.RegisterMessage(Details_737)

Lka_767 = _reflection.GeneratedProtocolMessageType('Lka_767', (_message.Message,), {
  'DESCRIPTOR' : _LKA_767,
  '__module__' : 'modules.drivers.proto.mobileye_pb2'
  # @@protoc_insertion_point(class_scope:apollo.drivers.Lka_767)
  })
_sym_db.RegisterMessage(Lka_767)

Lka_766 = _reflection.GeneratedProtocolMessageType('Lka_766', (_message.Message,), {
  'DESCRIPTOR' : _LKA_766,
  '__module__' : 'modules.drivers.proto.mobileye_pb2'
  # @@protoc_insertion_point(class_scope:apollo.drivers.Lka_766)
  })
_sym_db.RegisterMessage(Lka_766)

Next_76d = _reflection.GeneratedProtocolMessageType('Next_76d', (_message.Message,), {
  'DESCRIPTOR' : _NEXT_76D,
  '__module__' : 'modules.drivers.proto.mobileye_pb2'
  # @@protoc_insertion_point(class_scope:apollo.drivers.Next_76d)
  })
_sym_db.RegisterMessage(Next_76d)

Details_739 = _reflection.GeneratedProtocolMessageType('Details_739', (_message.Message,), {
  'DESCRIPTOR' : _DETAILS_739,
  '__module__' : 'modules.drivers.proto.mobileye_pb2'
  # @@protoc_insertion_point(class_scope:apollo.drivers.Details_739)
  })
_sym_db.RegisterMessage(Details_739)

Details_73a = _reflection.GeneratedProtocolMessageType('Details_73a', (_message.Message,), {
  'DESCRIPTOR' : _DETAILS_73A,
  '__module__' : 'modules.drivers.proto.mobileye_pb2'
  # @@protoc_insertion_point(class_scope:apollo.drivers.Details_73a)
  })
_sym_db.RegisterMessage(Details_73a)

Details_73b = _reflection.GeneratedProtocolMessageType('Details_73b', (_message.Message,), {
  'DESCRIPTOR' : _DETAILS_73B,
  '__module__' : 'modules.drivers.proto.mobileye_pb2'
  # @@protoc_insertion_point(class_scope:apollo.drivers.Details_73b)
  })
_sym_db.RegisterMessage(Details_73b)

Mobileye = _reflection.GeneratedProtocolMessageType('Mobileye', (_message.Message,), {
  'DESCRIPTOR' : _MOBILEYE,
  '__module__' : 'modules.drivers.proto.mobileye_pb2'
  # @@protoc_insertion_point(class_scope:apollo.drivers.Mobileye)
  })
_sym_db.RegisterMessage(Mobileye)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/map/relative_map/proto/navigator_config.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/map/relative_map/proto/navigator_config.proto',
  package='apollo.relative_map',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n5modules/map/relative_map/proto/navigator_config.proto\x12\x13\x61pollo.relative_map\"\x83\x02\n\x0bSampleParam\x12#\n\x18straight_sample_interval\x18\x01 \x01(\x01:\x01\x33\x12&\n\x1bsmall_kappa_sample_interval\x18\x02 \x01(\x01:\x01\x31\x12)\n\x1cmiddle_kappa_sample_interval\x18\x03 \x01(\x01:\x03\x30.4\x12(\n\x1blarge_kappa_sample_interval\x18\x04 \x01(\x01:\x03\x30.1\x12\x1a\n\x0bsmall_kappa\x18\x05 \x01(\x01:\x05\x30.002\x12\x1b\n\x0cmiddle_kappa\x18\x06 \x01(\x01:\x05\x30.008\x12\x19\n\x0blarge_kappa\x18\x07 \x01(\x01:\x04\x30.02\"t\n\x0fNavigatorConfig\x12)\n\x1b\x65nable_navigator_downsample\x18\x01 \x01(\x08:\x04true\x12\x36\n\x0csample_param\x18\x02 \x01(\x0b\x32 .apollo.relative_map.SampleParam'
)




_SAMPLEPARAM = _descriptor.Descriptor(
  name='SampleParam',
  full_name='apollo.relative_map.SampleParam',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='straight_sample_interval', full_name='apollo.relative_map.SampleParam.straight_sample_interval', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(3),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='small_kappa_sample_interval', full_name='apollo.relative_map.SampleParam.small_kappa_sample_interval', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(1),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='middle_kappa_sample_interval', full_name='apollo.relative_map.SampleParam.middle_kappa_sample_interval', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0.4),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='large_kappa_sample_interval', full_name='apollo.relative_map.SampleParam.large_kappa_sample_interval', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0.1),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='small_kappa', full_name='apollo.relative_map.SampleParam.small_kappa', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0.002),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='middle_kappa', full_name='apollo.relative_map.SampleParam.middle_kappa', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0.008),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='large_kappa', full_name='apollo.relative_map.SampleParam.large_kappa', index=6,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0.02),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=79,
  serialized_end=338,
)


_NAVIGATORCONFIG = _descriptor.Descriptor(
  name='NavigatorConfig',
  full_name='apollo.relative_map.NavigatorConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='enable_navigator_downsample', full_name='apollo.relative_map.NavigatorConfig.enable_navigator_downsample', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=True,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sample_param', full_name='apollo.relative_map.NavigatorConfig.sample_param', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=340,
  serialized_end=456,
)

_NAVIGATORCONFIG.fields_by_name['sample_param'].message_type = _SAMPLEPARAM
DESCRIPTOR.message_types_by_name['SampleParam'] = _SAMPLEPARAM
DESCRIPTOR.message_types_by_name['NavigatorConfig'] = _NAVIGATORCONFIG
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

SampleParam = _reflection.GeneratedProtocolMessageType('SampleParam', (_message.Message,), {
  'DESCRIPTOR' : _SAMPLEPARAM,
  '__module__' : 'modules.map.relative_map.proto.navigator_config_pb2'
  # @@protoc_insertion_point(class_scope:apollo.relative_map.SampleParam)
  })
_sym_db.RegisterMessage(SampleParam)

NavigatorConfig = _reflection.GeneratedProtocolMessageType('NavigatorConfig', (_message.Message,), {
  'DESCRIPTOR' : _NAVIGATORCONFIG,
  '__module__' : 'modules.map.relative_map.proto.navigator_config_pb2'
  # @@protoc_insertion_point(class_scope:apollo.relative_map.NavigatorConfig)
  })
_sym_db.RegisterMessage(NavigatorConfig)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/planning/proto/traffic_rule_config.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/planning/proto/traffic_rule_config.proto',
  package='apollo.planning',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n0modules/planning/proto/traffic_rule_config.proto\x12\x0f\x61pollo.planning\"7\n\x15\x42\x61\x63ksideVehicleConfig\x12\x1e\n\x13\x62\x61\x63kside_lane_width\x18\x01 \x01(\x01:\x01\x34\"\x8e\x02\n\x0f\x43rosswalkConfig\x12\x18\n\rstop_distance\x18\x01 \x01(\x01:\x01\x31\x12 \n\x15max_stop_deceleration\x18\x02 \x01(\x01:\x01\x34\x12\x1e\n\x13min_pass_s_distance\x18\x03 \x01(\x01:\x01\x31\x12\"\n\x17max_valid_stop_distance\x18\x04 \x01(\x01:\x01\x33\x12\x1c\n\x11\x65xpand_s_distance\x18\x05 \x01(\x01:\x01\x32\x12!\n\x16stop_strict_l_distance\x18\x06 \x01(\x01:\x01\x34\x12 \n\x15stop_loose_l_distance\x18\x07 \x01(\x01:\x01\x35\x12\x18\n\x0cstop_timeout\x18\x08 \x01(\x01:\x02\x31\x30\"/\n\x11\x44\x65stinationConfig\x12\x1a\n\rstop_distance\x18\x01 \x01(\x01:\x03\x30.5\"\xa6\x01\n\x0fKeepClearConfig\x12$\n\x16\x65nable_keep_clear_zone\x18\x01 \x01(\x08:\x04true\x12\x1d\n\x0f\x65nable_junction\x18\x02 \x01(\x08:\x04true\x12\x1e\n\x13min_pass_s_distance\x18\x03 \x01(\x01:\x01\x32\x12.\n!align_with_traffic_sign_tolerance\x18\x04 \x01(\x01:\x03\x34.5\"b\n\x16ReferenceLineEndConfig\x12\x1a\n\rstop_distance\x18\x01 \x01(\x01:\x03\x30.5\x12,\n min_reference_line_remain_length\x18\x02 \x01(\x01:\x02\x35\x30\"N\n\x0fReroutingConfig\x12\x18\n\rcooldown_time\x18\x01 \x01(\x01:\x01\x33\x12!\n\x16prepare_rerouting_time\x18\x02 \x01(\x01:\x01\x32\"A\n\x0eStopSignConfig\x12\x15\n\x07\x65nabled\x18\x01 \x01(\x08:\x04true\x12\x18\n\rstop_distance\x18\x02 \x01(\x01:\x01\x31\"g\n\x12TrafficLightConfig\x12\x15\n\x07\x65nabled\x18\x01 \x01(\x08:\x04true\x12\x18\n\rstop_distance\x18\x02 \x01(\x01:\x01\x31\x12 \n\x15max_stop_deceleration\x18\x03 \x01(\x01:\x01\x34\"c\n\x0fYieldSignConfig\x12\x15\n\x07\x65nabled\x18\x01 \x01(\x08:\x04true\x12\x18\n\rstop_distance\x18\x02 \x01(\x01:\x01\x31\x12\x1f\n\x14start_watch_distance\x18\x03 \x01(\x01:\x01\x32\"\xac\x06\n\x11TrafficRuleConfig\x12:\n\x07rule_id\x18\x01 \x01(\x0e\x32).apollo.planning.TrafficRuleConfig.RuleId\x12\x0f\n\x07\x65nabled\x18\x02 \x01(\x08\x12\x42\n\x10\x62\x61\x63kside_vehicle\x18\x03 \x01(\x0b\x32&.apollo.planning.BacksideVehicleConfigH\x00\x12\x35\n\tcrosswalk\x18\x04 \x01(\x0b\x32 .apollo.planning.CrosswalkConfigH\x00\x12\x39\n\x0b\x64\x65stination\x18\x05 \x01(\x0b\x32\".apollo.planning.DestinationConfigH\x00\x12\x36\n\nkeep_clear\x18\x06 \x01(\x0b\x32 .apollo.planning.KeepClearConfigH\x00\x12\x45\n\x12reference_line_end\x18\x07 \x01(\x0b\x32\'.apollo.planning.ReferenceLineEndConfigH\x00\x12\x35\n\trerouting\x18\x08 \x01(\x0b\x32 .apollo.planning.ReroutingConfigH\x00\x12\x34\n\tstop_sign\x18\t \x01(\x0b\x32\x1f.apollo.planning.StopSignConfigH\x00\x12<\n\rtraffic_light\x18\n \x01(\x0b\x32#.apollo.planning.TrafficLightConfigH\x00\x12\x36\n\nyield_sign\x18\x0b \x01(\x0b\x32 .apollo.planning.YieldSignConfigH\x00\"\xa7\x01\n\x06RuleId\x12\x14\n\x10\x42\x41\x43KSIDE_VEHICLE\x10\x01\x12\r\n\tCROSSWALK\x10\x02\x12\x0f\n\x0b\x44\x45STINATION\x10\x03\x12\x0e\n\nKEEP_CLEAR\x10\x04\x12\x16\n\x12REFERENCE_LINE_END\x10\x05\x12\r\n\tREROUTING\x10\x06\x12\r\n\tSTOP_SIGN\x10\x07\x12\x11\n\rTRAFFIC_LIGHT\x10\x08\x12\x0e\n\nYIELD_SIGN\x10\tB\x08\n\x06\x63onfig\"H\n\x12TrafficRuleConfigs\x12\x32\n\x06\x63onfig\x18\x01 \x03(\x0b\x32\".apollo.planning.TrafficRuleConfig'
)



_TRAFFICRULECONFIG_RULEID = _descriptor.EnumDescriptor(
  name='RuleId',
  full_name='apollo.planning.TrafficRuleConfig.RuleId',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='BACKSIDE_VEHICLE', index=0, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CROSSWALK', index=1, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DESTINATION', index=2, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='KEEP_CLEAR', index=3, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='REFERENCE_LINE_END', index=4, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='REROUTING', index=5, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STOP_SIGN', index=6, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TRAFFIC_LIGHT', index=7, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='YIELD_SIGN', index=8, number=9,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1706,
  serialized_end=1873,
)
_sym_db.RegisterEnumDescriptor(_TRAFFICRULECONFIG_RULEID)


_BACKSIDEVEHICLECONFIG = _descriptor.Descriptor(
  name='BacksideVehicleConfig',
  full_name='apollo.planning.BacksideVehicleConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='backside_lane_width', full_name='apollo.planning.BacksideVehicleConfig.backside_lane_width', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(4),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=69,
  serialized_end=124,
)


_CROSSWALKCONFIG = _descriptor.Descriptor(
  name='CrosswalkConfig',
  full_name='apollo.planning.CrosswalkConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='stop_distance', full_name='apollo.planning.CrosswalkConfig.stop_distance', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(1),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_stop_deceleration', full_name='apollo.planning.CrosswalkConfig.max_stop_deceleration', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(4),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='min_pass_s_distance', full_name='apollo.planning.CrosswalkConfig.min_pass_s_distance', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(1),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_valid_stop_distance', full_name='apollo.planning.CrosswalkConfig.max_valid_stop_distance', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(3),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='expand_s_distance', full_name='apollo.planning.CrosswalkConfig.expand_s_distance', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(2),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stop_strict_l_distance', full_name='apollo.planning.CrosswalkConfig.stop_strict_l_distance', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(4),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stop_loose_l_distance', full_name='apollo.planning.CrosswalkConfig.stop_loose_l_distance', index=6,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(5),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stop_timeout', full_name='apollo.planning.CrosswalkConfig.stop_timeout', index=7,
      number=8, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(10),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=127,
  serialized_end=397,
)


_DESTINATIONCONFIG = _descriptor.Descriptor(
  name='DestinationConfig',
  full_name='apollo.planning.DestinationConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='stop_distance', full_name='apollo.planning.DestinationConfig.stop_distance', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0.5),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=399,
  serialized_end=446,
)


_KEEPCLEARCONFIG = _descriptor.Descriptor(
  name='KeepClearConfig',
  full_name='apollo.planning.KeepClearConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='enable_keep_clear_zone', full_name='apollo.planning.KeepClearConfig.enable_keep_clear_zone', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=True,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enable_junction', full_name='apollo.planning.KeepClearConfig.enable_junction', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=True,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='min_pass_s_distance', full_name='apollo.planning.KeepClearConfig.min_pass_s_distance', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(2),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='align_with_traffic_sign_tolerance', full_name='apollo.planning.KeepClearConfig.align_with_traffic_sign_tolerance', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(4.5),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=449,
  serialized_end=615,
)


_REFERENCELINEENDCONFIG = _descriptor.Descriptor(
  name='ReferenceLineEndConfig',
  full_name='apollo.planning.ReferenceLineEndConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='stop_distance', full_name='apollo.planning.ReferenceLineEndConfig.stop_distance', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0.5),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='min_reference_line_remain_length', full_name='apollo.planning.ReferenceLineEndConfig.min_reference_line_remain_length', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(50),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=617,
  serialized_end=715,
)


_REROUTINGCONFIG = _descriptor.Descriptor(
  name='ReroutingConfig',
  full_name='apollo.planning.ReroutingConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cooldown_time', full_name='apollo.planning.ReroutingConfig.cooldown_time', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(3),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='prepare_rerouting_time', full_name='apollo.planning.ReroutingConfig.prepare_rerouting_time', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(2),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=717,
  serialized_end=795,
)


_STOPSIGNCONFIG = _descriptor.Descriptor(
  name='StopSignConfig',
  full_name='apollo.planning.StopSignConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='enabled', full_name='apollo.planning.StopSignConfig.enabled', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=True,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stop_distance', full_name='apollo.planning.StopSignConfig.stop_distance', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(1),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=797,
  serialized_end=862,
)


_TRAFFICLIGHTCONFIG = _descriptor.Descriptor(
  name='TrafficLightConfig',
  full_name='apollo.planning.TrafficLightConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='enabled', full_name='apollo.planning.TrafficLightConfig.enabled', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=True,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stop_distance', full_name='apollo.planning.TrafficLightConfig.stop_distance', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(1),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_stop_deceleration', full_name='apollo.planning.TrafficLightConfig.max_stop_deceleration', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(4),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=864,
  serialized_end=967,
)


_YIELDSIGNCONFIG = _descriptor.Descriptor(
  name='YieldSignConfig',
  full_name='apollo.planning.YieldSignConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='enabled', full_name='apollo.planning.YieldSignConfig.enabled', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=True,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stop_distance', full_name='apollo.planning.YieldSignConfig.stop_distance', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(1),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='start_watch_distance', full_name='apollo.planning.YieldSignConfig.start_watch_distance', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(2),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=969,
  serialized_end=1068,
)


_TRAFFICRULECONFIG = _descriptor.Descriptor(
  name='TrafficRuleConfig',
  full_name='apollo.planning.TrafficRuleConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='rule_id', full_name='apollo.planning.TrafficRuleConfig.rule_id', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enabled', full_name='apollo.planning.TrafficRuleConfig.enabled', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='backside_vehicle', full_name='apollo.planning.TrafficRuleConfig.backside_vehicle', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='crosswalk', full_name='apollo.planning.TrafficRuleConfig.crosswalk', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='destination', full_name='apollo.planning.TrafficRuleConfig.destination', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='keep_clear', full_name='apollo.planning.TrafficRuleConfig.keep_clear', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reference_line_end', full_name='apollo.planning.TrafficRuleConfig.reference_line_end', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rerouting', full_name='apollo.planning.TrafficRuleConfig.rerouting', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stop_sign', full_name='apollo.planning.TrafficRuleConfig.stop_sign', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='traffic_light', full_name='apollo.planning.TrafficRuleConfig.traffic_light', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='yield_sign', full_name='apollo.planning.TrafficRuleConfig.yield_sign', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _TRAFFICRULECONFIG_RULEID,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='config', full_name='apollo.planning.TrafficRuleConfig.config',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=1071,
  serialized_end=1883,
)


_TRAFFICRULECONFIGS = _descriptor.Descriptor(
  name='TrafficRuleConfigs',
  full_name='apollo.planning.TrafficRuleConfigs',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='config', full_name='apollo.planning.TrafficRuleConfigs.config', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1885,
  serialized_end=1957,
)

_TRAFFICRULECONFIG.fields_by_name['rule_id'].enum_type = _TRAFFICRULECONFIG_RULEID
_TRAFFICRULECONFIG.fields_by_name['backside_vehicle'].message_type = _BACKSIDEVEHICLECONFIG
_TRAFFICRULECONFIG.fields_by_name['crosswalk'].message_type = _CROSSWALKCONFIG
_TRAFFICRULECONFIG.fields_by_name['destination'].message_type = _DESTINATIONCONFIG
_TRAFFICRULECONFIG.fields_by_name['keep_clear'].message_type = _KEEPCLEARCONFIG
_TRAFFICRULECONFIG.fields_by_name['reference_line_end'].message_type = _REFERENCELINEENDCONFIG
_TRAFFICRULECONFIG.fields_by_name['rerouting'].message_type = _REROUTINGCONFIG
_TRAFFICRULECONFIG.fields_by_name['stop_sign'].message_type = _STOPSIGNCONFIG
_TRAFFICRULECONFIG.fields_by_name['traffic_light'].message_type = _TRAFFICLIGHTCONFIG
_TRAFFICRULECONFIG.fields_by_name['yield_sign'].message_type = _YIELDSIGNCONFIG
_TRAFFICRULECONFIG_RULEID.containing_type = _TRAFFICRULECONFIG
_TRAFFICRULECONFIG.oneofs_by_name['config'].fields.append(
  _TRAFFICRULECONFIG.fields_by_name['backside_vehicle'])
_TRAFFICRULECONFIG.fields_by_name['backside_vehicle'].containing_oneof = _TRAFFICRULECONFIG.oneofs_by_name['config']
_TRAFFICRULECONFIG.oneofs_by_name['config'].fields.append(
  _TRAFFICRULECONFIG.fields_by_name['crosswalk'])
_TRAFFICRULECONFIG.fields_by_name['crosswalk'].containing_oneof = _TRAFFICRULECONFIG.oneofs_by_name['config']
_TRAFFICRULECONFIG.oneofs_by_name['config'].fields.append(
  _TRAFFICRULECONFIG.fields_by_name['destination'])
_TRAFFICRULECONFIG.fields_by_name['destination'].containing_oneof = _TRAFFICRULECONFIG.oneofs_by_name['config']
_TRAFFICRULECONFIG.oneofs_by_name['config'].fields.append(
  _TRAFFICRULECONFIG.fields_by_name['keep_clear'])
_TRAFFICRULECONFIG.fields_by_name['keep_clear'].containing_oneof = _TRAFFICRULECONFIG.oneofs_by_name['config']
_TRAFFICRULECONFIG.oneofs_by_name['config'].fields.append(
  _TRAFFICRULECONFIG.fields_by_name['reference_line_end'])
_TRAFFICRULECONFIG.fields_by_name['reference_line_end'].containing_oneof = _TRAFFICRULECONFIG.oneofs_by_name['config']
_TRAFFICRULECONFIG.oneofs_by_name['config'].fields.append(
  _TRAFFICRULECONFIG.fields_by_name['rerouting'])
_TRAFFICRULECONFIG.fields_by_name['rerouting'].containing_oneof = _TRAFFICRULECONFIG.oneofs_by_name['config']
_TRAFFICRULECONFIG.oneofs_by_name['config'].fields.append(
  _TRAFFICRULECONFIG.fields_by_name['stop_sign'])
_TRAFFICRULECONFIG.fields_by_name['stop_sign'].containing_oneof = _TRAFFICRULECONFIG.oneofs_by_name['config']
_TRAFFICRULECONFIG.oneofs_by_name['config'].fields.append(
  _TRAFFICRULECONFIG.fields_by_name['traffic_light'])
_TRAFFICRULECONFIG.fields_by_name['traffic_light'].containing_oneof = _TRAFFICRULECONFIG.oneofs_by_name['config']
_TRAFFICRULECONFIG.oneofs_by_name['config'].fields.append(
  _TRAFFICRULECONFIG.fields_by_name['yield_sign'])
_TRAFFICRULECONFIG.fields_by_name['yield_sign'].containing_oneof = _TRAFFICRULECONFIG.oneofs_by_name['config']
_TRAFFICRULECONFIGS.fields_by_name['config'].message_type = _TRAFFICRULECONFIG
DESCRIPTOR.message_types_by_name['BacksideVehicleConfig'] = _BACKSIDEVEHICLECONFIG
DESCRIPTOR.message_types_by_name['CrosswalkConfig'] = _CROSSWALKCONFIG
DESCRIPTOR.message_types_by_name['DestinationConfig'] = _DESTINATIONCONFIG
DESCRIPTOR.message_types_by_name['KeepClearConfig'] = _KEEPCLEARCONFIG
DESCRIPTOR.message_types_by_name['ReferenceLineEndConfig'] = _REFERENCELINEENDCONFIG
DESCRIPTOR.message_types_by_name['ReroutingConfig'] = _REROUTINGCONFIG
DESCRIPTOR.message_types_by_name['StopSignConfig'] = _STOPSIGNCONFIG
DESCRIPTOR.message_types_by_name['TrafficLightConfig'] = _TRAFFICLIGHTCONFIG
DESCRIPTOR.message_types_by_name['YieldSignConfig'] = _YIELDSIGNCONFIG
DESCRIPTOR.message_types_by_name['TrafficRuleConfig'] = _TRAFFICRULECONFIG
DESCRIPTOR.message_types_by_name['TrafficRuleConfigs'] = _TRAFFICRULECONFIGS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

BacksideVehicleConfig = _reflection.GeneratedProtocolMessageType('BacksideVehicleConfig', (_message.Message,), {
  'DESCRIPTOR' : _BACKSIDEVEHICLECONFIG,
  '__module__' : 'modules.planning.proto.traffic_rule_config_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning.BacksideVehicleConfig)
  })
_sym_db.RegisterMessage(BacksideVehicleConfig)

CrosswalkConfig = _reflection.GeneratedProtocolMessageType('CrosswalkConfig', (_message.Message,), {
  'DESCRIPTOR' : _CROSSWALKCONFIG,
  '__module__' : 'modules.planning.proto.traffic_rule_config_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning.CrosswalkConfig)
  })
_sym_db.RegisterMessage(CrosswalkConfig)

DestinationConfig = _reflection.GeneratedProtocolMessageType('DestinationConfig', (_message.Message,), {
  'DESCRIPTOR' : _DESTINATIONCONFIG,
  '__module__' : 'modules.planning.proto.traffic_rule_config_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning.DestinationConfig)
  })
_sym_db.RegisterMessage(DestinationConfig)

KeepClearConfig = _reflection.GeneratedProtocolMessageType('KeepClearConfig', (_message.Message,), {
  'DESCRIPTOR' : _KEEPCLEARCONFIG,
  '__module__' : 'modules.planning.proto.traffic_rule_config_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning.KeepClearConfig)
  })
_sym_db.RegisterMessage(KeepClearConfig)

ReferenceLineEndConfig = _reflection.GeneratedProtocolMessageType('ReferenceLineEndConfig', (_message.Message,), {
  'DESCRIPTOR' : _REFERENCELINEENDCONFIG,
  '__module__' : 'modules.planning.proto.traffic_rule_config_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning.ReferenceLineEndConfig)
  })
_sym_db.RegisterMessage(ReferenceLineEndConfig)

ReroutingConfig = _reflection.GeneratedProtocolMessageType('ReroutingConfig', (_message.Message,), {
  'DESCRIPTOR' : _REROUTINGCONFIG,
  '__module__' : 'modules.planning.proto.traffic_rule_config_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning.ReroutingConfig)
  })
_sym_db.RegisterMessage(ReroutingConfig)

StopSignConfig = _reflection.GeneratedProtocolMessageType('StopSignConfig', (_message.Message,), {
  'DESCRIPTOR' : _STOPSIGNCONFIG,
  '__module__' : 'modules.planning.proto.traffic_rule_config_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning.StopSignConfig)
  })
_sym_db.RegisterMessage(StopSignConfig)

TrafficLightConfig = _reflection.GeneratedProtocolMessageType('TrafficLightConfig', (_message.Message,), {
  'DESCRIPTOR' : _TRAFFICLIGHTCONFIG,
  '__module__' : 'modules.planning.proto.traffic_rule_config_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning.TrafficLightConfig)
  })
_sym_db.RegisterMessage(TrafficLightConfig)

YieldSignConfig = _reflection.GeneratedProtocolMessageType('YieldSignConfig', (_message.Message,), {
  'DESCRIPTOR' : _YIELDSIGNCONFIG,
  '__module__' : 'modules.planning.proto.traffic_rule_config_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning.YieldSignConfig)
  })
_sym_db.RegisterMessage(YieldSignConfig)

TrafficRuleConfig = _reflection.GeneratedProtocolMessageType('TrafficRuleConfig', (_message.Message,), {
  'DESCRIPTOR' : _TRAFFICRULECONFIG,
  '__module__' : 'modules.planning.proto.traffic_rule_config_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning.TrafficRuleConfig)
  })
_sym_db.RegisterMessage(TrafficRuleConfig)

TrafficRuleConfigs = _reflection.GeneratedProtocolMessageType('TrafficRuleConfigs', (_message.Message,), {
  'DESCRIPTOR' : _TRAFFICRULECONFIGS,
  '__module__' : 'modules.planning.proto.traffic_rule_config_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning.TrafficRuleConfigs)
  })
_sym_db.RegisterMessage(TrafficRuleConfigs)


# @@protoc_insertion_point(module_scope)
